Usage — django-shortwave v0.9.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-shortwave v0.9.1 documentation »

# Usage

## Read Shortwave Instructions

First you need to understand what Shortwave is and does. (Hopefully you know that by this point.) Read through the homepage and the default commands file.

## Create Wave File

Visit `<your_site>/<admin_url>/shortwave/wave/add/`. Here you can create a custom wave, which is simply a collection of commands.

At a minimum you must choose a user. You can change options and add more commands later. Click “Save and continue editing”.

The wave is now saved and can be viewed in its raw form by click the “View on site” link at the top of the page.

## Save The Bookmarklet

Copy the URL of the raw wave file, paste it into the commands file URL field, and save the bookmarklet.

All that’s left is for you to use it.

### Navigation

- index
- modules |
- next |
- previous |
- django-shortwave v0.9.1 documentation »